'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var DEFAULT_ROOT_PATH = exports.DEFAULT_ROOT_PATH = '$';

// this works for showNonenumerable === false
var isExpandableNoShowNonenumerable = function isExpandableNoShowNonenumerable(data) {
  return (typeof data === 'undefined' ? 'undefined' : _typeof(data)) === 'object' && data !== null && Object.keys(data).length > 0;
};

// this works for showNonenumerable === true
var isExpandableShowNonenumerable = function isExpandableShowNonenumerable(data) {
  return (typeof data === 'undefined' ? 'undefined' : _typeof(data)) === 'object' && data !== null || typeof data === 'function';
};

// generate isExpandable function
var getIsExpandable = exports.getIsExpandable = function getIsExpandable(showNonenumerable) {
  if (!showNonenumerable) return isExpandableNoShowNonenumerable;
  return isExpandableShowNonenumerable;
};

var getPathsState = exports.getPathsState = function getPathsState(showNonenumerable, expandLevel, expandPaths, data, rootName) {
  var initialState = arguments.length <= 5 || arguments[5] === undefined ? {} : arguments[5];

  var isExpandable = getIsExpandable(showNonenumerable);
  var wildcardPaths = [];
  if (expandLevel !== undefined) {
    wildcardPaths = wildcardPaths.concat(wildcardPathsFromLevel(expandLevel));
  }

  wildcardPaths = wildcardPaths.concat(expandPaths);

  var paths = pathsFromWildcardPaths(isExpandable, wildcardPaths, data, DEFAULT_ROOT_PATH);
  var pathsState = paths.reduce(function (obj, path) {
    obj[path] = true;return obj;
  }, initialState);

  return pathsState;
};

/**
 * Convert wild card paths to concrete paths by recursive traversal
 */
var pathsFromWildcardPaths = exports.pathsFromWildcardPaths = function pathsFromWildcardPaths(isExpandable, wildcardPaths, data) {
  var paths = [];
  if (wildcardPaths === undefined) {
    return paths;
  }
  wildcardPaths.map(function (wildcardPath) {
    if (typeof wildcardPath === 'string') {
      (function () {
        // wildcard names
        // recursively populate paths with wildcard paths

        var populatePaths = function populatePaths(curObject, curPath, i) {
          var WILDCARD = "*";
          if (i === names.length) {
            paths.push(curPath);
            return;
          }
          var name = names[i];
          if (i === 0) {
            if (isExpandable(curObject) && (name === DEFAULT_ROOT_PATH || name === WILDCARD)) {
              populatePaths(curObject, DEFAULT_ROOT_PATH, i + 1);
            }
          } else {
            if (name === WILDCARD) {
              // matches anything
              for (var propertyName in curObject) {
                if (curObject.hasOwnProperty(propertyName)) {
                  var propertyValue = curObject[propertyName];
                  if (isExpandable(propertyValue)) {
                    populatePaths(propertyValue, curPath + '.' + propertyName, i + 1);
                  } else {
                    continue;
                  }
                }
              }
            } else {
              var _propertyValue = curObject[name];
              if (isExpandable(_propertyValue)) {
                populatePaths(_propertyValue, curPath + '.' + name, i + 1);
              }
            }
          }
        };

        var names = wildcardPath.split('.');
        populatePaths(data, '', 0);
      })();
    }
  });
  return paths;
};

var wildcardPathsFromLevel = exports.wildcardPathsFromLevel = function wildcardPathsFromLevel(level) {
  if (level < 0) {
    return undefined;
  }
  if (level === 0) {
    return [];
  }
  var path = DEFAULT_ROOT_PATH;
  var wildcardPaths = [path];
  for (var i = 1; i < level; i++) {
    path += '.*';
    wildcardPaths.push(path);
  }
  return wildcardPaths;
};

/*
export const pathsFromDataAndLevel = (data, level) => {
  const wildcardPaths = wildcardPathsFromLevel(level)
  return pathsFromWildcardPaths(wildcardPaths, data)
}
*/